@@ -435,7 +435,7 @@ class Prolog( NonTerminal ):
 class DocType( NonTerminal ):
     """class to handle `doctype` grammar. Note that DTDs are deprecated in
     HTML5. We will have to wait and see how it evolves under HTML5.
-
+    
     +-------------------------+-----------------------------------------------+
     | ttl doctype name        | Transted to html                              |
     +=========================+===============================================+
@@ -488,7 +488,6 @@ class DocType( NonTerminal ):
     +-------------------------+-----------------------------------------------+
     | html                    | <!DOCTYPE html>                               |
     +-------------------------+-----------------------------------------------+
-
     """
 
     dtdurls = {
@@ -912,11 +911,14 @@ class TagLine( NonTerminal ):
     def children( self ):
         return list( filter( None, (self.tagspans, self.NEWLINES) ))
 
+    def genhandle( self, igen, *args, **kwargs ):
+        self.tagspans.genhandle( igen, *args, **kwargs )
+
     def generate( self, igen, *args, **kwargs ):
         igen.comment( "lineno:%s" % self.tagspans.TAGBEGIN.lineno )
         super().generate( igen, *args, **kwargs )
         if not isinstance( self.parent, TagBlock ):
-            igen.handletag()
+            self.genhandle( igen, *args, **kwargs )
 
     def show( self, buf=sys.stdout, offset=0, attrnames=False,
               showcoord=False ):
@@ -928,14 +930,25 @@ class TagLine( NonTerminal ):
         [x.show(buf, offset+2, attrnames, showcoord) for x in self.children()]
 
 class TagSpans( NonTerminal ):
-    """class to handle `tagspan` grammar. TagSpans go through a twisted logic
+    """class to handle `tagspans` grammar. TagSpans go through a twisted logic
     of reverse generate() using self.parent. Be careful when changing this
     code !!!"""
 
+    iprune = False
+    """Boolean, if True, should remove all whitespaces before and after the 
+    content enclosed by this tag."""
+
+    oprune = False
+    """Boolean, if True, should remove all leading and trailining whitespaces
+    around this tag element."""
+
     def __init__( self, parser, tagspans, tagbegin, text ) :
         super().__init__( parser, tagspans, tagbegin, text )
         self.tagspans, self.TAGBEGIN, self.text = tagspans, tagbegin, text
         # Set parent attribute for children, should be last statement !!
+        tbtext = tagbegin.dump(None)
+        self.oprune = '!' in tbtext.split(' ', 1)[0]
+        self.iprune = '!' in tbtext.rsplit(' ', 1)[-1]
         self.setparent( self, self.children() )
 
     def children( self ):
@@ -953,6 +966,10 @@ class TagSpans( NonTerminal ):
             return self.tagspans.right_recursive( ts, TAGBEGIN, text )
         return ts
 
+    def genhandle( self, igen, *args, **kwargs ):
+        igen.handletag(
+                indent=False, nl='', iprune=self.iprune, oprune=self.oprune )
+
     def generate( self, igen, *args, **kwargs ):
         from  tayra.lexer import TTLLexer
         # TAGBEGIN
@@ -976,7 +993,7 @@ class TagSpans( NonTerminal ):
             self.tagspans.generate( igen, *args, **kwargs )
 
         if isinstance( self.parent, TagSpans ) :
-            igen.handletag()
+            self.genhandle( igen, *args, **kwargs )
 
     def show( self, buf=sys.stdout, offset=0, attrnames=False,
               showcoord=False ):
@@ -1004,7 +1021,7 @@ class TagBlock( NonTerminal ):
 
     def generate( self, igen, *args, **kwargs ):
         super().generate( igen, *args, **kwargs )
-        igen.handletag()
+        self.tagline.genhandle( igen, *args, **kwargs )
 
     def show( self, buf=sys.stdout, offset=0, attrnames=False,
               showcoord=False ):
@@ -1069,7 +1086,7 @@ class TextSpan( NonTerminal ):
 
     def generate( self, igen, *args, **kwargs ):
         super().generate( igen, *args, **kwargs )
-        igen.handletag()
+        self.tagspans.genhandle( igen, *args, **kwargs )
 
     def show( self, buf=sys.stdout, offset=0, attrnames=False,
               showcoord=False ):
